summaryrefslogtreecommitdiffstats
path: root/test/integration/targets/ansible-test-container/runme.py
diff options
context:
space:
mode:
authorMatt Martz <matt@sivel.net>2024-03-13 19:31:59 +0100
committerGitHub <noreply@github.com>2024-03-13 19:31:59 +0100
commit86f48a526ab0959cb964eac54c9bebb7f7a4dce1 (patch)
tree737f48a425dd70568bd98857f83bf94e08aebee3 /test/integration/targets/ansible-test-container/runme.py
parentdebconf: allow a list for value when vtype is multiselect (#82757) (diff)
downloadansible-86f48a526ab0959cb964eac54c9bebb7f7a4dce1.tar.xz
ansible-86f48a526ab0959cb964eac54c9bebb7f7a4dce1.zip
Install crun from Alpine 3.19 for known musl compatibility (#82812)
Diffstat (limited to 'test/integration/targets/ansible-test-container/runme.py')
-rwxr-xr-xtest/integration/targets/ansible-test-container/runme.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/integration/targets/ansible-test-container/runme.py b/test/integration/targets/ansible-test-container/runme.py
index 81b3ea9edf..498e8e7b80 100755
--- a/test/integration/targets/ansible-test-container/runme.py
+++ b/test/integration/targets/ansible-test-container/runme.py
@@ -1077,9 +1077,9 @@ class ApkBootstrapper(Bootstrapper):
packages = ['docker', 'podman', 'openssl', 'crun', 'ip6tables']
run_command('apk', 'add', *packages)
# 3.18 only contains crun 1.8.4, to get 1.9.2 to resolve the run/shm issue, install crun from edge
# Remove once we update to 3.19
- run_command('apk', 'upgrade', '-U', '--repository=http://dl-cdn.alpinelinux.org/alpine/edge/community', 'crun')
+ run_command('apk', 'upgrade', '-U', '--repository=http://dl-cdn.alpinelinux.org/alpine/v3.19/community', 'crun')
run_command('service', 'docker', 'start')
run_command('modprobe', 'tun')
@@ -1077,9 +1077,9 @@ class ApkBootstrapper(Bootstrapper):
packages = ['docker', 'podman', 'openssl', 'crun', 'ip6tables']
run_command('apk', 'add', *packages)
- # 3.18 only contains crun 1.8.4, to get 1.9.2 to resolve the run/shm issue, install crun from edge
+ # 3.18 only contains crun 1.8.4, to get 1.9.2 to resolve the run/shm issue, install crun from 3.19
# Remove once we update to 3.19